# Release history

#### 1.3.0
Add md files.

#### 1.2.0
Dependency update 1.60.0 - 2.0.0.

#### 1.1.0
Force CDK dependency update to 1.44.0.

#### 1.0.7
Fix dependencies.

#### 1.0.6
Various bugs fixed related to custom resource. Added more logging
for better debugging. Improved kwargs fixer. Improved cfn 
response sender.

#### 1.0.5
Implement a fail-safe for json dumps.

#### 1.0.4
Human error fix.

#### 1.0.3
Fix kwargs by converting string-integers to integers.

#### 1.0.2
Mitigate CloudFormation bug.

#### 1.0.1
Do not have global boto3 resources/clients.

#### 1.0.0
Initial project. Not tested. No extensive readme.
